@@ -24,10 +24,13 @@ import java.sql.Connection;
 import java.text.DateFormat;
 import java.text.DecimalFormat;
 import java.text.SimpleDateFormat;
+import java.util.ArrayList;
 import java.util.HashMap;
+import java.util.List;
 import java.util.Locale;
 
 import net.sf.jasperreports.engine.JRException;
+import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperFillManager;
 import net.sf.jasperreports.engine.JasperPrint;
@@ -46,25 +49,21 @@ import net.sf.jasperreports.engine.design.JasperDesign;
 import net.sf.jasperreports.engine.export.JRHtmlExporterParameter;
 import net.sf.jasperreports.engine.export.JRXhtmlExporter;
 
-import org.apache.commons.lang.StringUtils;
-import org.glom.libglom.Document;
-import org.glom.libglom.Field.glom_field_type;
-import org.glom.libglom.Formatting;
-import org.glom.libglom.Glom;
-import org.glom.libglom.LayoutFieldVector;
-import org.glom.libglom.LayoutGroup;
-import org.glom.libglom.LayoutItemVector;
-import org.glom.libglom.LayoutItem_Field;
-import org.glom.libglom.LayoutItem_GroupBy;
-import org.glom.libglom.LayoutItem_VerticalGroup;
-import org.glom.libglom.NumericFormat;
-import org.glom.libglom.Relationship;
-import org.glom.libglom.Report;
-import org.glom.libglom.SortClause;
-import org.glom.libglom.SortFieldPair;
-import org.glom.libglom.SqlBuilder;
-import org.glom.libglom.SqlExpr;
-import org.glom.libglom.Value;
+import org.apache.commons.lang3.StringUtils;
+import org.glom.web.server.libglom.Document;
+import org.glom.web.shared.TypedDataItem;
+import org.glom.web.shared.libglom.Field.GlomFieldType;
+import org.glom.web.shared.libglom.NumericFormat;
+import org.glom.web.shared.libglom.Report;
+import org.glom.web.shared.libglom.layout.Formatting;
+import org.glom.web.shared.libglom.layout.LayoutGroup;
+import org.glom.web.shared.libglom.layout.LayoutItem;
+import org.glom.web.shared.libglom.layout.LayoutItemField;
+import org.glom.web.shared.libglom.layout.SortClause;
+import org.glom.web.shared.libglom.layout.UsesRelationship;
+import org.glom.web.shared.libglom.layout.reportparts.LayoutItemGroupBy;
+import org.glom.web.shared.libglom.layout.reportparts.LayoutItemVerticalGroup;
+import org.jooq.Condition;
 
 /**
  * @author Murray Cumming <murrayc@openimus.com>
@@ -72,7 +71,7 @@ import org.glom.libglom.Value;
  */
 public class ReportGenerator {
 
-	private class Position {
+	private static class Position {
 		public Position(final int x, final int y) {
 			this.x = x;
 			this.y = y;
@@ -91,7 +90,7 @@ public class ReportGenerator {
 	// An arbitrary width, because we must specify _some_ width:
 	final int width = 100; // Points, as specified later.
 
-	LayoutFieldVector fieldsToGet = new LayoutFieldVector();
+	List<LayoutItemField> fieldsToGet = new ArrayList<LayoutItemField>();
 	SortClause sortClause = new SortClause();
 	String localeID;
 
@@ -106,12 +105,12 @@ public class ReportGenerator {
 
 	/**
 	 */
-	public String generateReport(final Document document, final String tableName, final Report report,
+	public String generateReport(final Document glomDocument, final String tableName, final Report report,
 			final Connection connection, final String quickFind) {
 
-		final org.glom.libglom.LayoutGroup layout_group = report.get_layout_group();
+		final LayoutGroup layout_group = report.getLayoutGroup();
 
-		design.setName(report.get_title(localeID)); // TODO: Actually, we want the title.
+		design.setName(report.getTitle(localeID)); // TODO: Actually, we want the title.
 
 		titleStyle.setName("Sans_Title");
 		titleStyle.setFontName("DejaVu Sans");
@@ -139,7 +138,7 @@ public class ReportGenerator {
 		final JRDesignBand titleBand = new JRDesignBand();
 		titleBand.setHeight(height);
 		final JRDesignStaticText staticTitle = new JRDesignStaticText();
-		staticTitle.setText(report.get_title(localeID));
+		staticTitle.setText(report.getTitle(localeID));
 		staticTitle.setY(0);
 		staticTitle.setX(0);
 		staticTitle.setWidth(width * 5); // No data will be shown without this.
@@ -155,7 +154,7 @@ public class ReportGenerator {
 		final JRDesignBand headerBand = new JRDesignBand();
 		headerBand.setHeight(height + 20);
 
-		fieldsToGet = new LayoutFieldVector();
+		fieldsToGet = new ArrayList<LayoutItemField>();
 		final int x = 0;
 		addGroupToReport(layout_group, detailBand, x, headerBand, 0);
 
@@ -164,20 +163,17 @@ public class ReportGenerator {
 
 		// Later versions of libglom actually return an empty SqlExpr when quickFindValue is empty,
 		// but let's be sure:
-		SqlExpr whereClause;
-		if (StringUtils.isEmpty(quickFind)) {
-			whereClause = new SqlExpr();
-		} else {
-			final Value quickFindValue = new Value(quickFind);
-			whereClause = Glom.get_find_where_clause_quick(document, tableName, quickFindValue);
+		Condition whereClause = null;
+		if (!StringUtils.isEmpty(quickFind)) {
+			final TypedDataItem quickFindValue = new TypedDataItem();
+			quickFindValue.setText(quickFind);
+			whereClause = SqlUtils.getFindWhereClauseQuick(glomDocument, tableName, quickFindValue);
 		}
 
 		String sqlQuery = "";
 		if (!fieldsToGet.isEmpty()) {
-			final Relationship extraJoin = new Relationship(); // Ignored.
-			final SqlBuilder builder = Glom.build_sql_select_with_where_clause(tableName, fieldsToGet, whereClause,
-					extraJoin, sortClause);
-			sqlQuery = Glom.sqlbuilder_get_full_query(builder);
+			sqlQuery = SqlUtils.buildSqlSelectWithWhereClause(tableName, fieldsToGet, whereClause,
+					sortClause);
 		} else {
 			Log.info("generateReport(): fieldsToGet is empty.");
 		}
@@ -197,7 +193,7 @@ public class ReportGenerator {
 		JasperPrint print;
 		try {
 			final HashMap<String, Object> parameters = new HashMap<String, Object>();
-			parameters.put("ReportTitle", report.get_title(localeID)); // TODO: Use the title, not the name.
+			parameters.put("ReportTitle", report.getTitle(localeID)); // TODO: Use the title, not the name.
 			print = JasperFillManager.fillReport(jasperreport, parameters, connection);
 		} catch (final JRException ex) {
 			ex.printStackTrace();
@@ -210,13 +206,13 @@ public class ReportGenerator {
 		// JasperExportManager.exportReportToXmlStream(print, output);
 		try {
 			final JRXhtmlExporter exporter = new JRXhtmlExporter();
-			exporter.setParameter(JRHtmlExporterParameter.JASPER_PRINT, print);
-			exporter.setParameter(JRHtmlExporterParameter.OUTPUT_STREAM, output);
+			exporter.setParameter(JRExporterParameter.JASPER_PRINT, print);
+			exporter.setParameter(JRExporterParameter.OUTPUT_STREAM, output);
 
 			// Use points instead of pixels for sizes, because pixels are silly
 			// in HTML:
 			exporter.setParameter(JRHtmlExporterParameter.SIZE_UNIT, "pt");
-			
+
 			// Avoid the page breaks, because they do not make sense for HTML:
 			// TODO: These do not seem to preven the page break gap.
 			exporter.setParameter(JRHtmlExporterParameter.IS_REMOVE_EMPTY_SPACE_BETWEEN_ROWS, Boolean.TRUE);
@@ -234,12 +230,12 @@ public class ReportGenerator {
 		// This does not work because jasperReports does not put individual rows in separate table rows.
 		// jasperReports just puts the whole thing in one table row.
 		// Remove the arbitrary width and height that JasperReports forced us to specify:
-		//html = html.replaceAll("position:absolute;", "");
-		//html = html.replaceAll("top:(\\d*)pt;", "");
-		//html = html.replaceAll("left:(\\d*)pt;", "");
-		//html = html.replaceAll("height:(\\d*)pt;", "");
-		//html = html.replaceAll("width:(\\d*)pt;", "");
-		//html = html.replaceAll("overflow: hidden;", "");
+		// html = html.replaceAll("position:absolute;", "");
+		// html = html.replaceAll("top:(\\d*)pt;", "");
+		// html = html.replaceAll("left:(\\d*)pt;", "");
+		// html = html.replaceAll("height:(\\d*)pt;", "");
+		// html = html.replaceAll("width:(\\d*)pt;", "");
+		// html = html.replaceAll("overflow: hidden;", "");
 
 		return html;
 	}
@@ -254,17 +250,17 @@ public class ReportGenerator {
 	 *            TODO
 	 * @param height
 	 */
-	private Position addVerticalGroupToReport(final org.glom.libglom.LayoutItem_VerticalGroup layout_group,
+	private Position addVerticalGroupToReport(final LayoutItemVerticalGroup layout_group,
 			final JRDesignBand parentBand, final Position pos) {
 		Position pos_result = new Position(pos);
 
-		final LayoutItemVector layoutItemsVec = layout_group.get_items();
+		final List<LayoutItem> layoutItemsVec = layout_group.getItems();
 		final int numItems = Utils.safeLongToInt(layoutItemsVec.size());
 		for (int i = 0; i < numItems; i++) {
-			final org.glom.libglom.LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
+			final LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
 
-			final LayoutItem_Field libglomLayoutItemField = LayoutItem_Field.cast_dynamic(libglomLayoutItem);
-			if (libglomLayoutItemField != null) {
+			if (libglomLayoutItem instanceof LayoutItemField) {
+				final LayoutItemField libglomLayoutItemField = (LayoutItemField) libglomLayoutItem;
 				pos_result = addFieldToDetailBandVertical(parentBand, pos_result, libglomLayoutItemField);
 				pos_result.x = pos.x;
 			} else {
@@ -288,17 +284,16 @@ public class ReportGenerator {
 	 *            TODO
 	 * @param height
 	 */
-	private Position addGroupToReport(final org.glom.libglom.LayoutGroup layout_group, final JRDesignBand parentBand,
-			final int x, final JRDesignBand headerBand, final int fieldTitlesY) {
+	private Position addGroupToReport(final LayoutGroup layout_group, final JRDesignBand parentBand, final int x,
+			final JRDesignBand headerBand, final int fieldTitlesY) {
 
 		Position pos_result = new Position(x, 0);
 
 		/**
 		 * * If this is a vertical group then we will lay the fields out vertically instead of horizontally.
 		 */
-		final org.glom.libglom.LayoutItem_VerticalGroup verticalGroup = LayoutItem_VerticalGroup
-				.cast_dynamic(layout_group);
-		if (verticalGroup != null) {
+		if (layout_group instanceof LayoutItemVerticalGroup) {
+			final LayoutItemVerticalGroup verticalGroup = (LayoutItemVerticalGroup) layout_group;
 			return addVerticalGroupToReport(verticalGroup, parentBand, pos_result);
 		}
 
@@ -306,20 +301,21 @@ public class ReportGenerator {
 		JRDesignBand fieldTitlesBand = headerBand;
 		int thisFieldTitlesY = fieldTitlesY; // If they are in a group title then they must be lower.
 
-		final LayoutItemVector layoutItemsVec = layout_group.get_items();
+		final List<LayoutItem> layoutItemsVec = layout_group.getItems();
 		final int numItems = Utils.safeLongToInt(layoutItemsVec.size());
 		for (int i = 0; i < numItems; i++) {
-			final org.glom.libglom.LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
+			final LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
 
-			final LayoutGroup libglomLayoutGroup = LayoutGroup.cast_dynamic(libglomLayoutItem);
-			final LayoutItem_Field libglomLayoutItemField = LayoutItem_Field.cast_dynamic(libglomLayoutItem);
-			if (libglomLayoutItemField != null) {
+			if (libglomLayoutItem instanceof LayoutItemField) {
+				final LayoutItemField libglomLayoutItemField = (LayoutItemField) libglomLayoutItem;
 				pos_result = addFieldToDetailBand(parentBand, headerBand, pos_result.x, libglomLayoutItemField,
 						thisFieldTitlesY, pos_result.y);
-			} else if (libglomLayoutGroup != null) {
-				final LayoutItem_GroupBy libglomGroupBy = LayoutItem_GroupBy.cast_dynamic(libglomLayoutGroup);
-				if (libglomGroupBy != null) {
-					final LayoutItem_Field fieldGroupBy = libglomGroupBy.get_field_group_by();
+			} else if (libglomLayoutItem instanceof LayoutGroup) {
+				final LayoutGroup libglomLayoutGroup = (LayoutGroup) libglomLayoutItem;
+
+				if (libglomLayoutGroup instanceof LayoutItemGroupBy) {
+					final LayoutItemGroupBy libglomGroupBy = (LayoutItemGroupBy) libglomLayoutGroup;
+					final LayoutItemField fieldGroupBy = libglomGroupBy.getFieldGroupBy();
 					if (fieldGroupBy == null)
 						continue;
 
@@ -331,9 +327,9 @@ public class ReportGenerator {
 					// We must sort by the group field,
 					// so that JasperReports can start a new group when its value changes.
 					// Note that this is not like a SQL GROUP BY.
-					final SortFieldPair pair = new SortFieldPair();
-					pair.setFirst(fieldGroupBy);
-					pair.setSecond(true); // Ascending.
+					final SortClause.SortField pair = new SortClause.SortField();
+					pair.field = fieldGroupBy;
+					pair.ascending = true;
 					sortClause.add(pair);
 
 					final JRDesignGroup group = new JRDesignGroup();
@@ -371,7 +367,7 @@ public class ReportGenerator {
 					int groupX = addFieldToGroupBand(groupBand, x, fieldGroupBy);
 
 					// Show the secondary fields:
-					final LayoutGroup groupSecondaries = libglomGroupBy.get_secondary_fields();
+					final LayoutGroup groupSecondaries = libglomGroupBy.getSecondaryFields();
 					if (groupSecondaries != null)
 						groupX = addSecondaryFieldsToGroupBand(groupSecondaries, groupBand, groupX);
 
@@ -398,18 +394,18 @@ public class ReportGenerator {
 		return pos_result;
 	}
 
-	private int addSecondaryFieldsToGroupBand(final org.glom.libglom.LayoutGroup layout_group,
-			final JRDesignBand groupBand, int x) {
-		final LayoutItemVector layoutItemsVec = layout_group.get_items();
+	private int addSecondaryFieldsToGroupBand(final LayoutGroup layout_group, final JRDesignBand groupBand, int x) {
+		final List<LayoutItem> layoutItemsVec = layout_group.getItems();
 		final int numItems = Utils.safeLongToInt(layoutItemsVec.size());
 		for (int i = 0; i < numItems; i++) {
-			final org.glom.libglom.LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
+			final LayoutItem libglomLayoutItem = layoutItemsVec.get(i);
 
-			final LayoutGroup libglomLayoutGroup = LayoutGroup.cast_dynamic(libglomLayoutItem);
-			final LayoutItem_Field libglomLayoutItemField = LayoutItem_Field.cast_dynamic(libglomLayoutItem);
-			if (libglomLayoutItemField != null) {
+			if (libglomLayoutItem instanceof LayoutItemField) {
+				final LayoutItemField libglomLayoutItemField = (LayoutItemField) libglomLayoutItem;
 				x = addFieldToGroupBand(groupBand, x, libglomLayoutItemField);
-			} else if (libglomLayoutGroup != null) {
+			} else if (libglomLayoutItem instanceof LayoutGroup) {
+				final LayoutGroup libglomLayoutGroup = (LayoutGroup) libglomLayoutItem;
+
 				// We do not expect LayoutItem_GroupBy in the secondary fields:
 				// final LayoutItem_GroupBy libglomGroupBy = LayoutItem_GroupBy.cast_dynamic(libglomLayoutGroup);
 
@@ -425,10 +421,10 @@ public class ReportGenerator {
 	 * @param libglomLayoutItemField
 	 * @return
 	 */
-	private JRDesignExpression createFieldExpression(final LayoutItem_Field libglomLayoutItemField) {
+	private JRDesignExpression createFieldExpression(final LayoutItemField libglomLayoutItemField) {
 		final JRDesignExpression expression = new JRDesignExpression();
 
-		final String fieldName = libglomLayoutItemField.get_name(); // TODO: Is this enough for related fields?
+		final String fieldName = libglomLayoutItemField.getName(); // TODO: Is this enough for related fields?
 
 		// TODO: Where is this format documented?
 		expression.setText("$F{" + fieldName + "}");
@@ -444,7 +440,7 @@ public class ReportGenerator {
 	 * @return
 	 */
 	private Position addFieldToDetailBand(final JRDesignBand parentBand, final JRDesignBand headerBand, final int x,
-			final LayoutItem_Field libglomLayoutItemField, final int fieldTitlesY, final int fieldY) {
+			final LayoutItemField libglomLayoutItemField, final int fieldTitlesY, final int fieldY) {
 		addField(libglomLayoutItemField);
 
 		// Show the field title:
@@ -470,7 +466,7 @@ public class ReportGenerator {
 	 * @return
 	 */
 	private Position addFieldToDetailBandVertical(final JRDesignBand parentBand, final Position pos,
-			final LayoutItem_Field libglomLayoutItemField) {
+			final LayoutItemField libglomLayoutItemField) {
 		addField(libglomLayoutItemField);
 
 		final Position pos_result = new Position(pos);
@@ -498,7 +494,7 @@ public class ReportGenerator {
 	}
 
 	private int addFieldToGroupBand(final JRDesignBand parentBand, final int x,
-			final LayoutItem_Field libglomLayoutItemField) {
+			final LayoutItemField libglomLayoutItemField) {
 		addField(libglomLayoutItemField);
 
 		final Position pos = new Position(x, 0);
@@ -526,7 +522,7 @@ public class ReportGenerator {
 	 * @param libglomLayoutItemField
 	 * @return
 	 */
-	private JRDesignTextField createFieldValueElement(final Position pos, final LayoutItem_Field libglomLayoutItemField) {
+	private JRDesignTextField createFieldValueElement(final Position pos, final LayoutItemField libglomLayoutItemField) {
 		final JRDesignTextField textField = new JRDesignTextField();
 
 		// Make sure this field starts at the right of the previous field,
@@ -543,39 +539,41 @@ public class ReportGenerator {
 		final JRDesignExpression expression = createFieldExpression(libglomLayoutItemField);
 		textField.setExpression(expression);
 
-		if (libglomLayoutItemField.get_glom_type() == glom_field_type.TYPE_NUMERIC) {
+		if (libglomLayoutItemField.getGlomType() == GlomFieldType.TYPE_NUMERIC) {
 			// Numeric formatting:
-			final Formatting formatting = libglomLayoutItemField.get_formatting_used();
-			final NumericFormat numericFormat = formatting.get_numeric_format();
+			final Formatting formatting = libglomLayoutItemField.getFormattingUsed();
+			final NumericFormat numericFormat = formatting.getNumericFormat();
 
 			final DecimalFormat format = new DecimalFormat();
-			format.setMaximumFractionDigits((int) numericFormat.get_decimal_places());
-			format.setGroupingUsed(numericFormat.get_use_thousands_separator());
+			format.setMaximumFractionDigits(numericFormat.getDecimalPlaces());
+			format.setGroupingUsed(numericFormat.getUseThousandsSeparator());
 
 			// TODO: Use numericFormat.get_currency_symbol(), possibly via format.setCurrency().
 			textField.setPattern(format.toPattern());
-		} else if (libglomLayoutItemField.get_glom_type() == glom_field_type.TYPE_DATE) {
+		} else if (libglomLayoutItemField.getGlomType() == GlomFieldType.TYPE_DATE) {
 			// Date formatting
 			// TODO: Use a 4-digit-year short form, somehow.
-			try //We use a try block because getDateInstance() is not guaranteed to return a SimpleDateFormat.
+			try // We use a try block because getDateInstance() is not guaranteed to return a SimpleDateFormat.
 			{
-			  final SimpleDateFormat format = (SimpleDateFormat)DateFormat.getDateInstance(DateFormat.SHORT, Locale.ROOT);
-
-			  textField.setPattern(format.toPattern());
-			} catch (final Exception ex) {
-				Log.info("ReportGenerator: The cast of SimpleDateFormat failed.");
-			}
-		} else if (libglomLayoutItemField.get_glom_type() == glom_field_type.TYPE_TIME) {
-			// Time formatting
-			try //We use a try block because getDateInstance() is not guaranteed to return a SimpleDateFormat.
-			{
-				final SimpleDateFormat format = (SimpleDateFormat)DateFormat.getTimeInstance(DateFormat.SHORT, Locale.ROOT);
+				final SimpleDateFormat format = (SimpleDateFormat) DateFormat.getDateInstance(DateFormat.SHORT,
+						Locale.ROOT);
 
 				textField.setPattern(format.toPattern());
 			} catch (final Exception ex) {
 				Log.info("ReportGenerator: The cast of SimpleDateFormat failed.");
 			}
-	}
+		} else if (libglomLayoutItemField.getGlomType() == GlomFieldType.TYPE_TIME) {
+			// Time formatting
+			try // We use a try block because getDateInstance() is not guaranteed to return a SimpleDateFormat.
+			{
+				final SimpleDateFormat format = (SimpleDateFormat) DateFormat.getTimeInstance(DateFormat.SHORT,
+						Locale.ROOT);
+
+				textField.setPattern(format.toPattern());
+			} catch (final Exception ex) {
+				Log.info("ReportGenerator: The cast of SimpleDateFormat failed.");
+			}
+		}
 
 		return textField;
 	}
@@ -588,10 +586,10 @@ public class ReportGenerator {
 	 * @return
 	 */
 	private JRDesignStaticText createFieldTitleElement(final Position pos,
-			final LayoutItem_Field libglomLayoutItemField, final boolean withColon) {
+			final LayoutItemField libglomLayoutItemField, final boolean withColon) {
 		final JRDesignStaticText textFieldColumn = new JRDesignStaticText();
 
-		String title = StringUtils.defaultString(libglomLayoutItemField.get_title(this.localeID));
+		String title = StringUtils.defaultString(libglomLayoutItemField.getTitle(this.localeID));
 
 		// If the title is at the left, instead of above, we need a : to show that it's a title.
 		if (withColon)
@@ -610,20 +608,20 @@ public class ReportGenerator {
 	 * @param libglomLayoutItemField
 	 * @return
 	 */
-	private String addField(final LayoutItem_Field libglomLayoutItemField) {
+	private String addField(final LayoutItemField libglomLayoutItemField) {
 
-		final String fieldName = libglomLayoutItemField.get_name(); // TODO: Is this enough for related fields?
+		final String fieldName = libglomLayoutItemField.getName(); // TODO: Is this enough for related fields?
 
 		// Avoid an unnamed field:
 		if (StringUtils.isEmpty(fieldName)) {
-			Log.info("addField(): Ignoring LayoutItem_Field with no field name");
+			Log.info("addField(): Ignoring LayoutItemField with no field name");
 			return fieldName;
 		}
 
 		// Avoid adding duplicate fields,
 		// because JasperDesign.addField() throws a "Duplicate declaration of field" exception.
 		for (int i = 0; i < fieldsToGet.size(); ++i) {
-			final LayoutItem_Field thisField = fieldsToGet.get(i);
+			final UsesRelationship thisField = fieldsToGet.get(i);
 			if (thisField.equals(libglomLayoutItemField))
 				return fieldName;
 		}
@@ -658,11 +656,11 @@ public class ReportGenerator {
 	 * @param libglomLayoutItemField
 	 * @return
 	 */
-	private Class<?> getClassTypeForGlomType(final LayoutItem_Field libglomLayoutItemField) {
+	private Class<?> getClassTypeForGlomType(final LayoutItemField libglomLayoutItemField) {
 		// Choose a suitable java class type for the SQL field:
 		Class<?> klass = null;
 
-		final glom_field_type glom_type = libglomLayoutItemField.get_glom_type();
+		final GlomFieldType glom_type = libglomLayoutItemField.getGlomType();
 		switch (glom_type) {
 		case TYPE_TEXT:
 			klass = java.lang.String.class;
@@ -684,10 +682,10 @@ public class ReportGenerator {
 			break;
 		case TYPE_INVALID:
 			Log.info("getClassTypeForGlomType() returning null for TYPE_INVALID glom type. Field name="
-					+ libglomLayoutItemField.get_layout_display_name());
+					+ libglomLayoutItemField.getLayoutDisplayName());
 		default:
 			Log.info("getClassTypeForGlomType() returning null for glom type: " + glom_type + ". Field name="
-					+ libglomLayoutItemField.get_layout_display_name());
+					+ libglomLayoutItemField.getLayoutDisplayName());
 			break;
 		}
 		return klass;
